@@ -85,7 +85,7 @@ class DBPluginInterface(ABC):
 
     @abstractmethod
     async def delete_knowledge(
-        self, tenant_id: str, knowledge_id_list: List[str]
+        self, tenant_id: str, knowledge_id_list: List[str], cascade: bool = False
     ) -> None:
         pass
 
@@ -291,7 +291,7 @@ class DBPluginInterface(ABC):
         pass
 
     @abstractmethod
-    async def get_space_rule(self, space_id: str) -> Optional[str]:
+    async def get_space_rule(self, tenant_id: str, space_id: str) -> Optional[str]:
         pass
 
     # =================== agent ===================
